//
// Copyright (c) 2003, 2013, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2015, 2021, Loongson Technology. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/ad_loongarch_64.hpp"

//------------------Pipeline Methods-----------------------------------------
#ifndef PRODUCT
const char * Pipeline::stageName(uint s) {
  static const char * const _stage_names[] = {
    "undefined", "IF", "ID", "RD", "CA", "WB", "CM"
  };

  return (s <= 6 ? _stage_names[s] : "???");
}
#endif

uint Pipeline::functional_unit_latency(uint start, const Pipeline *pred) const {
  // See if the functional units overlap
  uint mask = resourcesUsedExclusively() & pred->resourcesUsedExclusively();
  if (mask == 0)
    return (start);

  for (uint i = 0; i < pred->resourceUseCount(); i++) {
    const Pipeline_Use_Element *predUse = pred->resourceUseElement(i);
    if (predUse->multiple())
      continue;

    for (uint j = 0; j < resourceUseCount(); j++) {
      const Pipeline_Use_Element *currUse = resourceUseElement(j);
      if (currUse->multiple())
        continue;

      if (predUse->used() & currUse->used()) {
        Pipeline_Use_Cycle_Mask x = predUse->mask();
        Pipeline_Use_Cycle_Mask y = currUse->mask();

        for ( y <<= start; x.overlaps(y); start++ )
          y <<= 1;
      }
    }
  }

  // There is the potential for overlap
  return (start);
}

// The following two routines assume that the root Pipeline_Use entity
// consists of exactly 1 element for each functional unit
// start is relative to the current cycle; used for latency-based info
uint Pipeline_Use::full_latency(uint delay, const Pipeline_Use &pred) const {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      uint min_delay = 8;
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        uint curr_delay = delay;
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= curr_delay; x.overlaps(y); curr_delay++ )
            y <<= 1;
        }
        if (min_delay > curr_delay)
          min_delay = curr_delay;
      }
      if (delay < min_delay)
      delay = min_delay;
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        const Pipeline_Use_Element *currUse = element(j);
        if (predUse->_used & currUse->_used) {
          Pipeline_Use_Cycle_Mask x = predUse->_mask;
          Pipeline_Use_Cycle_Mask y = currUse->_mask;

          for ( y <<= delay; x.overlaps(y); delay++ )
            y <<= 1;
        }
      }
    }
  }

  return (delay);
}

void Pipeline_Use::add_usage(const Pipeline_Use &pred) {
  for (uint i = 0; i < pred._count; i++) {
    const Pipeline_Use_Element *predUse = pred.element(i);
    if (predUse->_multiple) {
      // Multiple possible functional units, choose first unused one
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        if ( !predUse->_mask.overlaps(currUse->_mask) ) {
          currUse->_used |= (1 << j);
          _resources_used |= (1 << j);
          currUse->_mask.Or(predUse->_mask);
          break;
        }
      }
    }
    else {
      for (uint j = predUse->_lb; j <= predUse->_ub; j++) {
        Pipeline_Use_Element *currUse = element(j);
        currUse->_used |= (1 << j);
        _resources_used |= (1 << j);
        currUse->_mask.Or(predUse->_mask);
      }
    }
  }
}

uint Pipeline::operand_latency(uint opnd, const Pipeline *pred) const {
  int const default_latency = 1;

  assert(this, "NULL pipeline info");
  assert(pred, "NULL predecessor pipline info");

  if (pred->hasFixedLatency())
    return (pred->fixedLatency());

  // If this is not an operand, then assume a dependence with 0 latency
  if (opnd > _read_stage_count)
    return (0);

  uint writeStage = pred->_write_stage;
  uint readStage  = _read_stages[opnd-1];

  if (writeStage == stage_undefined || readStage == stage_undefined)
    return (default_latency);

  int delta = writeStage - readStage;
  if (delta < 0) delta = 0;

  return (delta);
}

Pipeline_Use_Cycle_Mask operator&(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask & in2._mask);
}

Pipeline_Use_Cycle_Mask operator|(const Pipeline_Use_Cycle_Mask &in1, const Pipeline_Use_Cycle_Mask &in2) {
  return Pipeline_Use_Cycle_Mask(in1._mask | in2._mask);
}

static const Pipeline pipeline_class_Zero_Instructions(0, 0, true, 0, 0, false, false, false, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

static const Pipeline pipeline_class_Unknown_Instructions(0, 0, true, 0, 0, false, true, true, false, NULL, NULL, NULL, Pipeline_Use(0, 0, 0, NULL));

const Pipeline_Use_Element Pipeline_Use::elaborated_elements[10] = {
  Pipeline_Use_Element(0, 0, 0, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 1, 1, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 2, 2, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 3, 3, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 4, 4, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 5, 5, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 6, 6, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 7, 7, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 8, 8, false, Pipeline_Use_Cycle_Mask(0)),
  Pipeline_Use_Element(0, 9, 9, false, Pipeline_Use_Cycle_Mask(0))
};

const Pipeline_Use Pipeline_Use::elaborated_use(0, 0, 10, (Pipeline_Use_Element *)&elaborated_elements[0]);


// Pipeline Class "ialu_regI_regI"
static const enum machPipelineStages pipeline_reads_001[2] = {
  stage_RD,
  stage_RD 
};

static const enum machPipelineStages pipeline_res_stages_001[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_CA,        // DECODE
  stage_CA,        // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_001[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  1, // DECODE
  1, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_001[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x030, 4, 5, true,  Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_001(((uint)stage_WB)+1, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x03f, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_mult"
static const enum machPipelineStages pipeline_res_stages_002[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_CA,        // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_002[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  1, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_002[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x020, 5, 5, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_002(((uint)stage_WB)+5, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x02f, 0x020,  2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "mulL_reg_reg"
static const Pipeline pipeline_class_003(((uint)stage_WB)+10, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x02f, 0x020,  2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_div"
static const Pipeline pipeline_class_004(((uint)stage_WB)+10, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x02f, 0x020,  2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_mod"
static const Pipeline pipeline_class_005(((uint)stage_WB)+10, 2, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_002,
  (uint * const) pipeline_res_cycles_002,
  Pipeline_Use(0x02f, 0x020,  2, (Pipeline_Use_Element *)&pipeline_res_mask_002[0]));

// Pipeline Class "ialu_regL_regL"
static const Pipeline pipeline_class_006((uint)stage_WB, 2, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x03f, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_regL_imm16"
static const enum machPipelineStages pipeline_reads_002[1] = {
  stage_RD 
};

static const Pipeline pipeline_class_007((uint)stage_WB, 1, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x03f, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_loadL"
static const enum machPipelineStages pipeline_res_stages_003[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_RD,        // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_003[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  1, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_003[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_008(((uint)stage_WB)+5, 1, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_storeL"
static const Pipeline pipeline_class_009((uint)stage_undefined, 2, false, 0, 2, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_regI_imm16"
static const Pipeline pipeline_class_010((uint)stage_WB, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x03f, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "ialu_regI_mov"
static const Pipeline pipeline_class_011((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_001,
  (uint * const) pipeline_res_cycles_001,
  Pipeline_Use(0x03f, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_001[0]));

// Pipeline Class "empty"
static const enum machPipelineStages pipeline_res_stages_004[10] = {
  stage_undefined, // D1
  stage_undefined, // D2
  stage_undefined, // D3
  stage_undefined, // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_004[10] = {
  0, // D1
  0, // D2
  0, // D3
  0, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline pipeline_class_012((uint)stage_undefined, 0, false, 0, 0, false, false, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x000, 0x000,  0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_jump"
static const enum machPipelineStages pipeline_res_stages_005[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_RD         // FPU2
};

static const uint pipeline_res_cycles_005[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  1  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_005[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x200, 9, 9, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_013((uint)stage_undefined, 0, false, 0, 0, false, true, false, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x20f, 0x200,  2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "pipe_alu_branch"
static const enum machPipelineStages pipeline_reads_003[3] = {
  stage_RD,
  stage_RD,
  stage_undefined 
};

static const Pipeline pipeline_class_014((uint)stage_undefined, 3, false, 0, 0, false, true, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x20f, 0x200,  2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "ialu_loadI"
static const Pipeline pipeline_class_015(((uint)stage_WB)+3, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "ialu_storeI"
static const Pipeline pipeline_class_016((uint)stage_undefined, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fpu_regF_regF"
static const enum machPipelineStages pipeline_res_stages_006[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_CA,        // ALU2
  stage_CA,        // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_006[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  1, // ALU2
  1, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_006[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x0c0, 6, 7, true,  Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_017((uint)stage_WB, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x0cf, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "fpu_div"
static const enum machPipelineStages pipeline_res_stages_007[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_CA,        // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_007[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  1, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_007[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x080, 7, 7, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_018((uint)stage_WB, 2, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x08f, 0x080,  2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "fcvt_I2D"
static const enum machPipelineStages pipeline_res_stages_008[10] = {
  stage_ID,        // D1
  stage_ID,        // D2
  stage_ID,        // D3
  stage_ID,        // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_CA,        // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_undefined  // FPU2
};

static const uint pipeline_res_cycles_008[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  1, // ALU2
  0, // ALU
  0, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_008[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x040, 6, 6, false, Pipeline_Use_Cycle_Mask(0x00000004)) 
};

static const Pipeline pipeline_class_019((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x04f, 0x040,  2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "fcvt_D2I"
static const Pipeline pipeline_class_020((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_008,
  (uint * const) pipeline_res_cycles_008,
  Pipeline_Use(0x04f, 0x040,  2, (Pipeline_Use_Element *)&pipeline_res_mask_008[0]));

// Pipeline Class "pipe_mfc1"
static const Pipeline pipeline_class_021((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "pipe_mtc1"
static const uint pipeline_res_cycles_009[10] = {
  1, // D1
  1, // D2
  1, // D3
  1, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  5, // FPU1
  0  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_009[2] = {
  Pipeline_Use_Element(0x00f, 0, 3, true,  Pipeline_Use_Cycle_Mask(0x00000001)),
  Pipeline_Use_Element(0x100, 8, 8, false, Pipeline_Use_Cycle_Mask(0x0000003e)) 
};

static const Pipeline pipeline_class_022((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_009,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_009[0]));

// Pipeline Class "fpu_sqrt"
static const Pipeline pipeline_class_023((uint)stage_WB, 2, false, 0, 0, false, true, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_007,
  (uint * const) pipeline_res_cycles_007,
  Pipeline_Use(0x08f, 0x080,  2, (Pipeline_Use_Element *)&pipeline_res_mask_007[0]));

// Pipeline Class "fpu_loadF"
static const Pipeline pipeline_class_024(((uint)stage_WB)+3, 1, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "fpu_storeF"
static const Pipeline pipeline_class_025((uint)stage_undefined, 2, false, 0, 1, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_001,
   (enum machPipelineStages * const) pipeline_res_stages_003,
  (uint * const) pipeline_res_cycles_003,
  Pipeline_Use(0x10f, 0x100,  2, (Pipeline_Use_Element *)&pipeline_res_mask_003[0]));

// Pipeline Class "pipe_fpu_branch"
static const Pipeline pipeline_class_026((uint)stage_undefined, 3, false, 0, 0, false, true, false, false,

  (enum machPipelineStages * const) pipeline_reads_003,
   (enum machPipelineStages * const) pipeline_res_stages_005,
  (uint * const) pipeline_res_cycles_005,
  Pipeline_Use(0x20f, 0x200,  2, (Pipeline_Use_Element *)&pipeline_res_mask_005[0]));

// Pipeline Class "fpu1_regF"
static const Pipeline pipeline_class_027((uint)stage_WB, 1, false, 0, 0, false, false, false, false,

  (enum machPipelineStages * const) pipeline_reads_002,
   (enum machPipelineStages * const) pipeline_res_stages_006,
  (uint * const) pipeline_res_cycles_006,
  Pipeline_Use(0x0cf, 0x000,  2, (Pipeline_Use_Element *)&pipeline_res_mask_006[0]));

// Pipeline Class "long_memory_op"
static const Pipeline pipeline_class_028((uint)stage_undefined, 0, true, 30, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x000, 0x000,  0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "simple_call"
static const enum machPipelineStages pipeline_res_stages_009[10] = {
  stage_undefined, // D1
  stage_undefined, // D2
  stage_undefined, // D3
  stage_undefined, // D4
  stage_undefined, // DECODE
  stage_undefined, // ALU1
  stage_undefined, // ALU2
  stage_undefined, // ALU
  stage_undefined, // FPU1
  stage_RD         // FPU2
};

static const uint pipeline_res_cycles_010[10] = {
  0, // D1
  0, // D2
  0, // D3
  0, // D4
  0, // DECODE
  0, // ALU1
  0, // ALU2
  0, // ALU
  0, // FPU1
  1  // FPU2
};

static const Pipeline_Use_Element pipeline_res_mask_010[1] = {
  Pipeline_Use_Element(0x200, 9, 9, false, Pipeline_Use_Cycle_Mask(0x00000002)) 
};

static const Pipeline pipeline_class_029((uint)stage_undefined, 0, true, 200, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_009,
  (uint * const) pipeline_res_cycles_010,
  Pipeline_Use(0x200, 0x200,  1, (Pipeline_Use_Element *)&pipeline_res_mask_010[0]));

// Pipeline Class "call"
static const Pipeline pipeline_class_030((uint)stage_undefined, 0, true, 200, 10, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x000, 0x000,  0, (Pipeline_Use_Element *)NULL));

// Pipeline Class "pipe_slow"
static const Pipeline pipeline_class_031((uint)stage_undefined, 0, true, 50, 20, false, true, true, false,
 NULL,  (enum machPipelineStages * const) pipeline_res_stages_004,
  (uint * const) pipeline_res_cycles_004,
  Pipeline_Use(0x000, 0x000,  0, (Pipeline_Use_Element *)NULL));

//------------------Inter-Instruction Latency--------------------------------
uint Node::latency(uint i) {
  uint j;
  // verify in legal range for inputs
  assert(i < len(), "index not in range");

  // verify input is not null
  Node *pred = in(i);
  if (!pred)
    return 0;

  if (pred->is_Proj())
    pred = pred->in(0);

  // if either node does not have pipeline info, use default
  const Pipeline *predpipe = pred->pipeline();
  assert(predpipe, "no predecessor pipeline info");

  if (predpipe->hasFixedLatency())
    return predpipe->fixedLatency();

  const Pipeline *currpipe = pipeline();
  assert(currpipe, "no pipeline info");

  if (!is_Mach())
    return 0;

  const MachNode *m = as_Mach();
  j = m->oper_input_base();
  if (i < j)
    return currpipe->functional_unit_latency(0, predpipe);

  // determine which operand this is in
  uint n = m->num_opnds();
  int delta = 0;

  uint k;
  for (k = 1; k < n; k++) {
    j += m->_opnds[k]->num_edges();
    if (i < j)
      break;
  }
  if (k < n)
    delta = currpipe->operand_latency(k,predpipe);

  return currpipe->functional_unit_latency(delta, predpipe);
}

// Descriptions for emitting different functional unit nops
void Bundle::initialize_nops(MachNode * nop_list[1], Compile *C) {
  nop_list[0] = (MachNode *) new (C) MachNopNode();
};

#ifndef PRODUCT
void Bundle::dump(outputStream *st) const {
  static const char * bundle_flags[] = {
    "",
    "use nop delay",
    "use unconditional delay",
    "use conditional delay",
    "used in conditional delay",
    "used in unconditional delay",
    "used in all conditional delays",
  };

  static const char *resource_names[10] = { "D1", "D2", "D3", "D4", "DECODE", "ALU1", "ALU2", "ALU", "FPU1", "FPU2" };

  bool needs_comma = false;

  if (_flags) {
    st->print("%s", bundle_flags[_flags]);
    needs_comma = true;
  };
  if (instr_count()) {
    st->print("%s%d instr%s", needs_comma ? ", " : "", instr_count(), instr_count() != 1 ? "s" : "");
    needs_comma = true;
  };
  uint r = resources_used();
  if (r) {
    st->print("%sresource%s:", needs_comma ? ", " : "", (r & (r-1)) != 0 ? "s" : "");
    for (uint i = 0; i < 10; i++)
      if ((r & (1 << i)) != 0)
        st->print(" %s", resource_names[i]);
    needs_comma = true;
  };
  st->print("\n");
}
#endif
const Pipeline *                            Node::pipeline_class() { return (&pipeline_class_Zero_Instructions); }
const Pipeline *                            Node::pipeline() const { return (&pipeline_class_Zero_Instructions); }

const Pipeline *                        MachNode::pipeline_class() { return (&pipeline_class_Unknown_Instructions); }
const Pipeline *                        MachNode::pipeline() const { return pipeline_class(); }



const Pipeline *                           loadINode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadINode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   loadI_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   loadI_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                         loadI2BNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadI2BNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        loadI2UBNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        loadI2UBNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                         loadI2SNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadI2SNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        loadI2USNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        loadI2USNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadLNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                           loadLNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                 loadL_unalignedNode::pipeline_class() { return (&pipeline_class_008); }
const Pipeline *                 loadL_unalignedNode::pipeline() const { return (&pipeline_class_008); }

const Pipeline *                      storeL_regNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                      storeL_regNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                   storeL_immL_0Node::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                   storeL_immL_0Node::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                      storeL_immNode::pipeline_class() { return (&pipeline_class_009); }
const Pipeline *                      storeL_immNode::pipeline() const { return (&pipeline_class_009); }

const Pipeline *                           loadNNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadNNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                         loadN2PNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadN2PNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadPNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadPNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                       loadKlassNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                       loadKlassNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                      loadNKlassNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                      loadNKlassNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                    loadN2PKlassNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                    loadN2PKlassNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        loadConINode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                        loadConINode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  loadConL_set64Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                  loadConL_set64Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                      loadConL12Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                      loadConL12Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 loadConL_immL_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 loadConL_immL_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                       loadRangeNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                       loadRangeNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storePNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storePNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                storeImmP_immP_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                storeImmP_immP_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                       storeImmBNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                       storeImmBNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                          storeNNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeNNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                        storeP2NNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                        storeP2NNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                     storeNKlassNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                     storeNKlassNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                   storeP2NKlassNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                   storeP2NKlassNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                storeImmN_immN_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                storeImmN_immN_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                          storeBNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeBNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  storeB_convL2INode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  storeB_convL2INode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadBNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadBNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   loadB_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   loadB_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          loadUBNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          loadUBNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                  loadUB_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                  loadUB_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                           loadSNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadSNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                         loadS2BNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadS2BNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   loadS_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   loadS_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                       storeImmINode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                       storeImmINode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                          storeINode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                          storeINode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  storeI_convL2INode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  storeI_convL2INode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadFNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadFNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                loadConP_generalNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                loadConP_generalNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           loadConP_no_oop_cheapNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           loadConP_no_oop_cheapNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   loadConP_pollNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   loadConP_pollNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 loadConP_immP_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 loadConP_immP_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 loadConN_immN_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 loadConN_immN_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                        loadConNNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                        loadConNNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   loadConNKlassNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   loadConNKlassNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  TailCalljmpIndNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                  TailCalljmpIndNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                 CreateExceptionNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                 CreateExceptionNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                RethrowExceptionNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                RethrowExceptionNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                     jmpDir_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                     jmpDir_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                 jmpLoopEnd_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                 jmpLoopEnd_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *        jmpLoopEnd_reg_immI_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *        jmpLoopEnd_reg_immI_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               jmpCon_flags_longNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *               jmpCon_flags_longNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *               branchConP_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *               branchConP_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *             branchConN2P_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *             branchConN2P_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                 branchConP_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                 branchConP_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *           cmpN_null_branch_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *           cmpN_null_branch_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *            cmpN_reg_branch_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *            cmpN_reg_branch_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConIU_reg_reg_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConIU_reg_reg_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConIU_reg_imm_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConIU_reg_imm_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConI_reg_reg_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *         branchConI_reg_reg_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *      branchConI_reg_immI_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *      branchConI_reg_immI_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConI_reg_imm_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *         branchConI_reg_imm_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *     branchConIU_reg_immI_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *     branchConIU_reg_immI_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *       branchConL_regL_regL_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *       branchConL_regL_regL_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *     branchConL_regL_immL_0_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *     branchConL_regL_immL_0_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *       branchConL_regL_immL_longNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *       branchConL_regL_immL_longNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *         branchConF_reg_reg_longNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *         branchConF_reg_reg_longNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *         branchConD_reg_reg_longNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *         branchConD_reg_reg_longNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    jmpDir_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                    jmpDir_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                jmpLoopEnd_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                jmpLoopEnd_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *       jmpLoopEnd_reg_immI_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *       jmpLoopEnd_reg_immI_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              jmpCon_flags_shortNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              jmpCon_flags_shortNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *              branchConP_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *              branchConP_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *            branchConN2P_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *            branchConN2P_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *                branchConP_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *                branchConP_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *          cmpN_null_branch_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *          cmpN_null_branch_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *           cmpN_reg_branch_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *           cmpN_reg_branch_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *       branchConIU_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *       branchConIU_reg_reg_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *       branchConIU_reg_imm_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *       branchConIU_reg_imm_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConI_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConI_reg_reg_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *     branchConI_reg_immI_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *     branchConI_reg_immI_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConI_reg_imm_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *        branchConI_reg_imm_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *    branchConIU_reg_immI_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *    branchConIU_reg_immI_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *      branchConL_regL_regL_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *      branchConL_regL_regL_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *    branchConL_regL_immL_0_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *    branchConL_regL_immL_0_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *      branchConL_regL_immL_shortNode::pipeline_class() { return (&pipeline_class_014); }
const Pipeline *      branchConL_regL_immL_shortNode::pipeline() const { return (&pipeline_class_014); }

const Pipeline *        branchConF_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *        branchConF_reg_reg_shortNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *        branchConD_reg_reg_shortNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *        branchConD_reg_reg_shortNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               CallRuntimeDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               CallRuntimeDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  membar_acquireNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                  membar_acquireNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                      load_fenceNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                      load_fenceNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *             membar_acquire_lockNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *             membar_acquire_lockNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                  membar_releaseNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  membar_releaseNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     store_fenceNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     store_fenceNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *             membar_release_lockNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *             membar_release_lockNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                 membar_volatileNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 membar_volatileNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *     unnecessary_membar_volatileNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *     unnecessary_membar_volatileNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *               membar_storestoreNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *               membar_storestoreNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                         castX2PNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *                         castX2PNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *                         castP2XNode::pipeline_class() { return (&pipeline_class_011); }
const Pipeline *                         castP2XNode::pipeline() const { return (&pipeline_class_011); }

const Pipeline *                 MoveF2I_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 MoveF2I_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                 MoveI2F_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 MoveI2F_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                 MoveD2L_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 MoveD2L_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                 MoveL2D_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 MoveL2D_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovN_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovN_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovN_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovN_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovP_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovP_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovN_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovN_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovN_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovN_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovN_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovN_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpU_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpU_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpN_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpN_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovL_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovL_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovD_cmpD_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovD_cmpD_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovF_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovF_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovD_cmpI_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovD_cmpI_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovD_cmpP_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovD_cmpP_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovI_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovI_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              cmovF_cmpF_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              cmovF_cmpF_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   cmpL3_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   cmpL3_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   cmpF3_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   cmpF3_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   cmpD3_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   cmpD3_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     clear_arrayNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     clear_arrayNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  string_compareNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  string_compareNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   string_equalsNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   string_equalsNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    addI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    addI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    addI_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    addI_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *      addI_salI_Reg_Reg_immI_1_4Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *      addI_salI_Reg_Reg_immI_1_4Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *    addI_salI_Reg_Reg_immI_1_4_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *    addI_salI_Reg_Reg_immI_1_4_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    addP_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    addP_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            addP_reg_reg_convI2LNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            addP_reg_reg_convI2LNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    addP_reg_immNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                    addP_reg_immNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *   addP_salL_Reg_RegI2L_immI_1_4Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *   addP_salL_Reg_RegI2L_immI_1_4Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    addL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    addL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    addL_Reg_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    addL_Reg_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 addL_RegI2L_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 addL_RegI2L_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 addL_RegI2L_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 addL_RegI2L_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               addL_RegI2L_Reg_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *               addL_RegI2L_Reg_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *              addL_RegI2L_RegI2LNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              addL_RegI2L_RegI2LNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            addL_RegI2L_RegI2L_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            addL_RegI2L_RegI2L_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 addL_Reg_RegI2LNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 addL_Reg_RegI2LNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *               addL_Reg_RegI2L_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *               addL_Reg_RegI2L_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    subI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    subI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *        subI_Reg_immI_M2047_2048Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *        subI_Reg_immI_M2047_2048Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                        negI_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                        negI_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                        negL_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                        negL_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *        subL_Reg_immL_M2047_2048Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *        subL_Reg_immL_M2047_2048Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    subL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    subL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 subL_Reg_RegI2LNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 subL_Reg_RegI2LNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 subL_RegI2L_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 subL_RegI2L_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *              subL_RegI2L_RegI2LNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              subL_RegI2L_RegI2LNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    modI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    modI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    modL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    modL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    mulI_Reg_RegNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                    mulI_Reg_RegNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                   maddI_Reg_RegNode::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                   maddI_Reg_RegNode::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                 maddI_Reg_Reg_0Node::pipeline_class() { return (&pipeline_class_002); }
const Pipeline *                 maddI_Reg_Reg_0Node::pipeline() const { return (&pipeline_class_002); }

const Pipeline *                    divI_Reg_RegNode::pipeline_class() { return (&pipeline_class_005); }
const Pipeline *                    divI_Reg_RegNode::pipeline() const { return (&pipeline_class_005); }

const Pipeline *                    divF_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    divF_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    divD_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    divD_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    mulL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    mulL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                 mulL_reg_regI2LNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                 mulL_reg_regI2LNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               mulL_reg_regI2L_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *               mulL_reg_regI2L_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    divL_reg_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    divL_reg_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    addF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    addF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    subF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    subF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    addD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    addD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    subD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    subD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                        negF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                        negF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                        negD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                        negD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    mulF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    mulF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                   maddF_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                   maddF_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                 maddF_reg_reg_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                 maddF_reg_reg_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                    mulD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                    mulD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                   maddD_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                   maddD_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                 maddD_reg_reg_0Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                 maddD_reg_reg_0Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                        absF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                        absF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                        absD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                        absD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                       sqrtD_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                       sqrtD_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                       sqrtF_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                       sqrtF_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                   andI_Reg_immINode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   andI_Reg_immINode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             andI_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             andI_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *       andI_Reg_immI_nonneg_maskNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *       andI_Reg_immI_nonneg_maskNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *       andL_Reg_immL_nonneg_maskNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *       andL_Reg_immL_nonneg_maskNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             xorI_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             xorI_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                xorI_Reg_immI_M1Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                xorI_Reg_immI_M1Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              xorL2I_Reg_immI_M1Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              xorL2I_Reg_immI_M1Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             xorL_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             xorL_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   lbu_and_lmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   lbu_and_lmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                 lbu_and_lmask_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                 lbu_and_lmask_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                   lbu_and_rmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                   lbu_and_rmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                    andI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    andI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andnI_Reg_nRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andnI_Reg_nRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andnI_Reg_nReg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andnI_Reg_nReg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   ornI_Reg_nRegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   ornI_Reg_nRegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 ornI_Reg_nReg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 ornI_Reg_nReg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  andnI_nReg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  andnI_nReg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andnI_nReg_Reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andnI_nReg_Reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   ornI_nReg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   ornI_nReg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 ornI_nReg_Reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 ornI_nReg_Reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    andL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    andL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            andL_Reg_Reg_convI2LNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            andL_Reg_Reg_convI2LNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          andL_Reg_Reg_convI2L_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          andL_Reg_Reg_convI2L_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             andL_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             andL_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           andL2I_Reg_imm_0_4095Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           andL2I_Reg_imm_0_4095Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andL_Reg_immL_M8Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andL_Reg_immL_M8Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andL_Reg_immL_M5Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andL_Reg_immL_M5Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andL_Reg_immL_M7Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andL_Reg_immL_M7Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                andL_Reg_immL_M4Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                andL_Reg_immL_M4Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              andL_Reg_immL_M121Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              andL_Reg_immL_M121Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     orL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                     orL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                  orL_Reg_P2XRegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                  orL_Reg_P2XRegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                orL_Reg_P2XReg_0Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                orL_Reg_P2XReg_0Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    xorL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    xorL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    salI_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    salI_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  salL2I_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                  salL2I_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *         salI_Reg_imm_and_M65536Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *         salI_Reg_imm_and_M65536Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                       land7_2_sNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                       land7_2_sNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                           ori2sNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                           ori2sNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                             i2sNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                             i2sNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                             i2bNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                             i2bNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 salI_RegL2I_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 salI_RegL2I_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    salI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    salI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                    salL_Reg_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    salL_Reg_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 salL_RegI2L_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                 salL_RegI2L_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    salL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    salL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    sarL_Reg_immNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    sarL_Reg_immNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *           sarL2I_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *           sarL2I_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    sarL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    sarL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    slrL_Reg_RegNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                    slrL_Reg_RegNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *              slrL_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              slrL_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *  slrL_Reg_immI_0_31_and_max_intNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *  slrL_Reg_immI_0_31_and_max_intNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *           slrL_P2XReg_immI_0_31Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *           slrL_P2XReg_immI_0_31Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             slrL_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *             slrL_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *           slrL_Reg_immI_convL2INode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *           slrL_Reg_immI_convL2INode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          slrL_P2XReg_immI_32_63Node::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          slrL_P2XReg_immI_32_63Node::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                    xorI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                    xorI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     orI_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     orI_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            rotI_shr_logical_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            rotI_shr_logical_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *          rotI_shr_logical_Reg_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *          rotI_shr_logical_Reg_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                 orI_Reg_castP2XNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                 orI_Reg_castP2XNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               orI_Reg_castP2X_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               orI_Reg_castP2X_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             shr_logical_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             shr_logical_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline * shr_logical_Reg_imm_nonneg_maskNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline * shr_logical_Reg_imm_nonneg_maskNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rolI_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rolI_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            rolI_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            rolI_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rolL_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rolL_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            rolL_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            rolL_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             rolL_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             rolL_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           rolL_Reg_immI_32_63_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           rolL_Reg_immI_32_63_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rorI_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rorI_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            rorI_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            rorI_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *              rorL_Reg_immI_0_31Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              rorL_Reg_immI_0_31Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *            rorL_Reg_immI_0_31_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *            rorL_Reg_immI_0_31_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             rorL_Reg_immI_32_63Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             rorL_Reg_immI_32_63Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           rorL_Reg_immI_32_63_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           rorL_Reg_immI_32_63_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             shr_logical_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             shr_logical_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               shr_arith_Reg_immNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               shr_arith_Reg_immNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *               shr_arith_Reg_RegNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *               shr_arith_Reg_RegNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                         convI2BNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                         convI2BNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                     convI2L_regNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                     convI2L_regNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                     convL2I_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     convL2I_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   convL2I2L_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   convL2I2L_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     convL2D_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     convL2D_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                convD2L_reg_fastNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                convD2L_reg_fastNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                convD2L_reg_slowNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                convD2L_reg_slowNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                convF2I_reg_fastNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                convF2I_reg_fastNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                convF2I_reg_slowNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                convF2I_reg_slowNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                convF2L_reg_fastNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                convF2L_reg_fastNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                convF2L_reg_slowNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                convF2L_reg_slowNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     convL2F_regNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     convL2F_regNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     convI2F_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                     convI2F_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                cmpLTMask_immI_0Node::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                cmpLTMask_immI_0Node::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       cmpLTMaskNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       cmpLTMaskNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         convP2BNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                         convP2BNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                 convI2D_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                 convI2D_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                 convF2D_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                 convF2D_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                 convD2F_reg_regNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                 convD2F_reg_regNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *            convD2I_reg_reg_fastNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *            convD2I_reg_reg_fastNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *            convD2I_reg_reg_slowNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *            convD2I_reg_reg_slowNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   encodeHeapOopNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                   encodeHeapOopNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          encodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          encodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                   decodeHeapOopNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *                   decodeHeapOopNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *          decodeHeapOop_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *          decodeHeapOop_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            encodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            encodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *            decodeKlass_not_nullNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *            decodeKlass_not_nullNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                        tlsLoadPNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        tlsLoadPNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                     checkCastPPNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                     checkCastPPNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                          castPPNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                          castPPNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                          castIINode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                          castIINode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                             RetNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                             RetNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                      tailjmpIndNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *                      tailjmpIndNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *            CallStaticJavaDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *            CallStaticJavaDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *           CallDynamicJavaDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *           CallDynamicJavaDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              CallLeafNoFPDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *              CallLeafNoFPDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       prefetchrNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       prefetchrNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                       prefetchwNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                       prefetchwNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   prefetchAllocNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   prefetchAllocNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                  CallLeafDirectNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                  CallLeafDirectNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                          loadUSNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          loadUSNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                  loadUS_convI2LNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                  loadUS_convI2LNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                          storeCNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                          storeCNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeC_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                        storeC_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                 loadConF_immF_0Node::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                 loadConF_immF_0Node::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                        loadConFNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                        loadConFNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                 loadConD_immD_0Node::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                 loadConD_immD_0Node::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                        loadConDNode::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                        loadConDNode::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                      storeF_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      storeF_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                   storeF_immF_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                   storeF_immF_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                           loadDNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                           loadDNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                 loadD_unalignedNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                 loadD_unalignedNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                      storeD_regNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                      storeD_regNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                   storeD_immD_0Node::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                   storeD_immD_0Node::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                         loadSSINode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadSSINode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeSSINode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                        storeSSINode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                         loadSSLNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadSSLNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeSSLNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                        storeSSLNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                         loadSSPNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadSSPNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeSSPNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                        storeSSPNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                         loadSSFNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadSSFNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeSSFNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        storeSSFNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                         loadSSDNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                         loadSSDNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                        storeSSDNode::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                        storeSSDNode::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                     cmpFastLockNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                     cmpFastLockNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   cmpFastUnlockNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   cmpFastUnlockNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                      storeImmCMNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                      storeImmCMNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *              ShouldNotReachHereNode::pipeline_class() { return (&pipeline_class_013); }
const Pipeline *              ShouldNotReachHereNode::pipeline() const { return (&pipeline_class_013); }

const Pipeline *                     leaP8NarrowNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                     leaP8NarrowNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *             leaPPosIdxScaleOff8Node::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *             leaPPosIdxScaleOff8Node::pipeline() const { return (&pipeline_class_010); }

const Pipeline *                    leaPIdxScaleNode::pipeline_class() { return (&pipeline_class_010); }
const Pipeline *                    leaPIdxScaleNode::pipeline() const { return (&pipeline_class_010); }

const Pipeline *             partialSubtypeCheckNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *             partialSubtypeCheckNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *               storePConditionalNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *               storePConditionalNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *               storeIConditionalNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *               storeIConditionalNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *               storeLConditionalNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *               storeLConditionalNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                     loadPLockedNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                     loadPLockedNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                 compareAndSwapINode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 compareAndSwapINode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 compareAndSwapLNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 compareAndSwapLNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 compareAndSwapPNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 compareAndSwapPNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                 compareAndSwapNNode::pipeline_class() { return (&pipeline_class_028); }
const Pipeline *                 compareAndSwapNNode::pipeline() const { return (&pipeline_class_028); }

const Pipeline *                    minI_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    minI_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                    maxI_Reg_RegNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                    maxI_Reg_RegNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                   maxI_Reg_zeroNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                   maxI_Reg_zeroNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *              zerox_long_reg_regNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *              zerox_long_reg_regNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                     combine_i2lNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                     combine_i2lNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                   combine_i2l_0Node::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *                   combine_i2l_0Node::pipeline() const { return (&pipeline_class_001); }

const Pipeline *             convI2L_reg_reg_zexNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *             convI2L_reg_reg_zexNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *           convL2I2L_reg_reg_zexNode::pipeline_class() { return (&pipeline_class_001); }
const Pipeline *           convL2I2L_reg_reg_zexNode::pipeline() const { return (&pipeline_class_001); }

const Pipeline *                  loadUI2L_rmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                  loadUI2L_rmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                  loadUI2L_lmaskNode::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                  loadUI2L_lmaskNode::pipeline() const { return (&pipeline_class_015); }

const Pipeline *                loadUI2L_lmask_0Node::pipeline_class() { return (&pipeline_class_015); }
const Pipeline *                loadUI2L_lmask_0Node::pipeline() const { return (&pipeline_class_015); }

const Pipeline *              safePoint_poll_regNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *              safePoint_poll_regNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  safePoint_pollNode::pipeline_class() { return (&pipeline_class_016); }
const Pipeline *                  safePoint_pollNode::pipeline() const { return (&pipeline_class_016); }

const Pipeline *                  roundFloat_nopNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                  roundFloat_nopNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *                 roundDouble_nopNode::pipeline_class() { return (&pipeline_class_012); }
const Pipeline *                 roundDouble_nopNode::pipeline() const { return (&pipeline_class_012); }

const Pipeline *              countLeadingZerosINode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              countLeadingZerosINode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *              countLeadingZerosLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *              countLeadingZerosLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             countTrailingZerosINode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *             countTrailingZerosINode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *             countTrailingZerosLNode::pipeline_class() { return (&pipeline_class_006); }
const Pipeline *             countTrailingZerosLNode::pipeline() const { return (&pipeline_class_006); }

const Pipeline *                          loadV8Node::pipeline_class() { return (&pipeline_class_024); }
const Pipeline *                          loadV8Node::pipeline() const { return (&pipeline_class_024); }

const Pipeline *                         storeV8Node::pipeline_class() { return (&pipeline_class_025); }
const Pipeline *                         storeV8Node::pipeline() const { return (&pipeline_class_025); }

const Pipeline *                      Repl8B_DSPNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                      Repl8B_DSPNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                          Repl8BNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                          Repl8BNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                  Repl8B_imm_DSPNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                  Repl8B_imm_DSPNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                      Repl8B_immNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                      Repl8B_immNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                     Repl8B_zeroNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                     Repl8B_zeroNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                       Repl8B_M1Node::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                       Repl8B_M1Node::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                      Repl4S_DSPNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                      Repl4S_DSPNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                          Repl4SNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                          Repl4SNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                  Repl4S_imm_DSPNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                  Repl4S_imm_DSPNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                      Repl4S_immNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                      Repl4S_immNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                     Repl4S_zeroNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                     Repl4S_zeroNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                       Repl4S_M1Node::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                       Repl4S_M1Node::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                          Repl2INode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                          Repl2INode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                      Repl2I_immNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                      Repl2I_immNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                     Repl2I_zeroNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                     Repl2I_zeroNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                       Repl2I_M1Node::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                       Repl2I_M1Node::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                          Repl2FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          Repl2FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                     Repl2F_zeroNode::pipeline_class() { return (&pipeline_class_022); }
const Pipeline *                     Repl2F_zeroNode::pipeline() const { return (&pipeline_class_022); }

const Pipeline *                          vadd2FNode::pipeline_class() { return (&pipeline_class_031); }
const Pipeline *                          vadd2FNode::pipeline() const { return (&pipeline_class_031); }

const Pipeline *                         vadd2F3Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                         vadd2F3Node::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                          vsub2FNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                          vsub2FNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                          vmul2FNode::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                          vmul2FNode::pipeline() const { return (&pipeline_class_017); }

const Pipeline *                         vmul2F3Node::pipeline_class() { return (&pipeline_class_017); }
const Pipeline *                         vmul2F3Node::pipeline() const { return (&pipeline_class_017); }
// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DLOONGARCH64=1
#ifndef LOONGARCH64
#  error "LOONGARCH64 must be defined"
#endif // LOONGARCH64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
